@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/kms/KMS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kms/KMS_EXPORTS.h>
 
-namespace Aws
-{
-namespace KMS
-{
-namespace Model
-{
-  enum class KeyMaterialState
-  {
-    NOT_SET,
-    NON_CURRENT,
-    CURRENT,
-    PENDING_ROTATION
-  };
+namespace Aws {
+namespace KMS {
+namespace Model {
+enum class KeyMaterialState { NOT_SET, NON_CURRENT, CURRENT, PENDING_ROTATION };
 
-namespace KeyMaterialStateMapper
-{
+namespace KeyMaterialStateMapper {
 AWS_KMS_API KeyMaterialState GetKeyMaterialStateForName(const Aws::String& name);
 
 AWS_KMS_API Aws::String GetNameForKeyMaterialState(KeyMaterialState value);
-} // namespace KeyMaterialStateMapper
-} // namespace Model
-} // namespace KMS
-} // namespace Aws
+}  // namespace KeyMaterialStateMapper
+}  // namespace Model
+}  // namespace KMS
+}  // namespace Aws
